@@ -3,12 +3,12 @@
 use strict;
 use warnings;
 
-use Mo::utils::Language qw(check_language_639_1);
+use Mo::utils::Language qw(check_language_639_2);
 
 my $self = {
-        'key' => 'en',
+        'key' => 'eng',
 };
-check_language_639_1($self, 'key');
+check_language_639_2($self, 'key');
 
 # Print out.
 print "ok\n";
